<?php

namespace RUMCWV;

if (!defined('ABSPATH')) {
  die('Let\'s not do this');
}

/**
 *RUM CWV Settings class, self contains the settings page and admin menu
 * - admin menu
 * - admin scripts
 * - admin styles
 * - admin toolbar
 **/
class RUMCWV_Settings
{
  public static function init()
  {

    add_action('admin_enqueue_scripts', 'RUMCWV\RUMCWV_Settings::rum_cwv_admin_scripts_styles');
    add_action('admin_bar_menu', 'RUMCWV\RUMCWV_Settings::cwv_toolbar', 100);
    add_action('admin_menu', 'RUMCWV\RUMCWV_Settings::rum_cwv_create_menu');

    add_action('wp_ajax_rum_cwv_save_options', 'RUMCWV\RUMCWV_Settings::save_options');
    add_filter('plugin_action_links_wp-rum/rumcorewebvitals.php', 'RUMCWV\RUMCWV_Settings::rum_cwvsettingslink');
  }


  /* settings link */
  public static function rum_cwvsettingslink($links,$file)
  {
    // Build and escape the URL.
    $url = esc_url(add_query_arg(
      'page',
      'rum_core_web_vitals',
      get_admin_url() . 'admin.php'
    ));
    // Create the link.
    $settings_link = "<a href='$url'>" . __('Settings') . '</a>';
    // Adds the link to the end of the array.
    array_push(
      $links,
      $settings_link
    );
    return $links;
  }



  public static function rum_cwv_admin_scripts_styles($hook)
  {

    if ($hook != 'settings_page_rum_core_web_vitals') {
      return;
    }
    wp_register_script('rum_cwv_settings_chartjs_script', RUM_CWV_PLUGIN_DIR . 'admin/js/chart.js', array('jquery'), RUM_CWV_VERSION);
    wp_register_script('rum_cwv_settings_chartjs_adapter_script', RUM_CWV_PLUGIN_DIR . 'admin/js/chartjs-adapter-date.js', array('jquery'), RUM_CWV_VERSION);
    wp_register_script('rum_cwv_settings_admin_script', RUM_CWV_PLUGIN_DIR . 'admin/js/settings.js', array('jquery'), RUM_CWV_VERSION);
    wp_register_style('rum_cwv_settings_admin_style', RUM_CWV_PLUGIN_DIR . 'admin/css/settings.css', [], RUM_CWV_VERSION);
    wp_enqueue_script('rum_cwv_settings_chartjs_script');
    wp_enqueue_script('rum_cwv_settings_chartjs_adapter_script');
    wp_enqueue_script('rum_cwv_settings_admin_script');
    wp_enqueue_style('rum_cwv_settings_admin_style');
  }

  /**
   * Create entry in options menu
   */
  public static function rum_cwv_create_menu()
  {
    add_options_page('RUM CWV', 'RUM CWV', 'manage_options', 'rum_core_web_vitals', 'RUMCWV\RUMCWV_Settings::rum_cwv_options_content', 0);
  }

  /**
   * Settings page
   */
  public static function rum_cwv_options_content()
  {
    include(RUM_CWV_PLUGIN_PATH . 'admin/html/settings.php');
  }

  /**
   * Add toolbar menu
   */
  public static function cwv_toolbar($admin_bar)
  {
    $admin_bar->add_menu(array(
      'id'    => 'rum_cwv_plugin',
      'title' => 'RUM',
      'href'  => get_admin_url() . 'options-general.php?page=rum_core_web_vitals'
    ));
  }



  public static function save_options()
  {
    if ( ! isset( $_POST['cwv_nonce'] ) || ! wp_verify_nonce( sanitize_text_field( wp_unslash ( $_POST['cwv_nonce'] ) ) , 'cwv_nonce' ) ){
      wp_die( 'Invalid nonce specified');
    }
  
    $rum_cwv_collect_rum = intval($_POST['rum_cwv_collect_rum']);
		$rum_cwv_sample_rate = intval($_POST['rum_cwv_sample_rate']);
		$rum_cwv_sample_retention = intval($_POST['rum_cwv_sample_retention']);

    $data = [
      'rum_cwv_collect_rum' => $rum_cwv_collect_rum,
      'rum_cwv_sample_rate' => $rum_cwv_sample_rate,
      'rum_cwv_sample_retention' => $rum_cwv_sample_retention,
    ];

    //add_option('rum_cwv_options',json_encode($_POST));
    update_option('rum_cwv_options', json_encode($data));
    wp_die('just saving da options');
  }
}
